@@ -7,10 +7,11 @@ pasw_ = ""
 db_ = None
 curs_ = "DEFAULT"
 mode_ = "MySQL"
+connection_ = None
 
 # Make this differently, for the love of god!
 def bake(host=host_, port=port_, user=user_, pasw=pasw_, db=db_, cursor=curs_, mode=mode_, file=None):
-    global host_, port_, user_, pasw_, db_, curs_, mode_
+    global host_, port_, user_, pasw_, db_, curs_, mode_, connection_
     if file is None:
         if host != "": host_=host
         if port != "": port_=port
@@ -31,14 +32,16 @@ def bake(host=host_, port=port_, user=user_, pasw=pasw_, db=db_, cursor=curs_, m
         if config.has_option(sect, "db"):   db_   = section["db"]
         if config.has_option(sect, "curs"): curs_ = section["curs"]
         if config.has_option(sect, "mode"): mode_ = section["mode"]
+    # Connection
+    if (mode_ == "PostgreSQL"):
+        conn = psycopg2.connect(host=host_, port=port_, user=user_, password=pasw_, database=db_)
+    else: # MySQL by Default
+        conn = pymysql.connect(host=host_, port=port_, user=user_, passwd=pasw_, db=db_)
+    connection_ = conn.cursor(pymysql.cursors.DictCursor) if curs_=="DICTIONARY" else conn.cursor()
 
 # A query.
 def query(query):
-    if (mode_ == "MySQL"):
-        conn = pymysql.connect(host=host_, port=port_, user=user_, passwd=pasw_, db=db_)
-    elif (mode_ == "PostgreSQL"):
-        conn = psycopg2.connect(host=host_, port=port_, user=user_, password=pasw_, database=db_)
-    conn_object = conn.cursor(pymysql.cursors.DictCursor) if curs_=="DICTIONARY" else conn.cursor()
+    conn_object = connection_
     conn_object.execute(query)
     if conn_object.pgresult_ptr is not None:
         response = conn_object.fetchall()
